Zone class

Constructors

Zone({required String id, required double radius, required List<LatLng> coordinates, int? notificationResponsivenessMs, List<GeofenceEventType> triggers = const [GeofenceEventType.enter, GeofenceEventType.exit, GeofenceEventType.dwell], Duration? expirationDuration, Duration? dwellLoiteringDelay, GeofenceEventType initialTrigger = GeofenceEventType.enter})
Zone.fromJson(Map<String, dynamic> json)
factory

Properties

coordinates → List<LatLng>
List of coordinates of the geofence zone.
final
dwellLoiteringDelay → Duration?
The time it will take to trigger the dwell event after the user enters the geofence zone.
final
expirationDuration → Duration?
The duration after which the geofence will expire.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
A unique identifier for the geofence zone.
final
initialTrigger → GeofenceEventType
The initial trigger for the geofence zone.
final
notificationResponsivenessMs → int?
The millisecond delay between entering the zone and receiving the notification.
final
radius → double
The radius of the geofence zone in meters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggers → List<GeofenceEventType>
The list of triggers that will be used to monitor the geofence zone.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited